<?php

declare(strict_types=1);

namespace Drupal\billwerk_subscriptions_handler_default\EventSubscriber;

use Drupal\billwerk_subscriptions\Event\SubscriberContractChangedEvent;
use Drupal\billwerk_subscriptions\LogHelper;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Subscriber to contract changes. Updates the user, whenever the Billwerk Contract changed.
 */
class SubscriberContractChangedEventSubscriber implements EventSubscriberInterface {

  /**
   * Constructs a SubscriberContractChangedEventSubscriber object.
   */
  public function __construct(
        protected readonly LogHelper $logHelper,
  ) {
  }

  /**
   *
   */
  public function onSubscriberContractChangedEvent(SubscriberContractChangedEvent $event): void {
    // @improve: We should sort out changes that are not relevant to the subscription, if it is possible and makes sense.
    // Trigger a refresh of the subscriber:
    $event->getSubscriber()->refreshFromBillwerkContractSubscription();
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents(): array {
    return [
      SubscriberContractChangedEvent::class => ['onSubscriberContractChangedEvent'],
    ];
  }

}
