<?php

declare(strict_types=1);

namespace Drupal\billwerk_subscriptions_handler_default\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure Billwerk Subscriptions Handler: Default settings for this site.
 */
final class SettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'billwerk_subscriptions_handler_default_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames(): array {
    return ['billwerk_subscriptions_handler_default.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $form = parent::buildForm($form, $form_state);
    $config = $this->config('billwerk_subscriptions_handler_default.settings');

    $form['settings'] = [
      '#type' => 'details',
      '#title' => $this->t('General settings'),
      '#open' => TRUE,
      '#description' => $this->t('General Billwerk Subscriptions Handler settings'),
      '#description_display' => 'after',
    ];

    $form['settings']['on_user_registration_create_subscription'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('On user creation create a Billwerk Subscription'),
      '#default_value' => $config->get('on_user_registration_create_subscription'),
      '#description' => $this->t('Creates a Billwerk Subscription and Customer through an order when a Drupal user is newly created.'),
    ];
    $form['settings']['billwerk_registration_plan_variant_id_sandbox'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Billwerk Plan Variant ID for registration (Sandbox)'),
      '#description' => $this->t('The Billwerk Plan Variant ID used for Billwerk Customer / Contract creation on Drupal user registration. Enter the plan variant id from the Sandbox environment here. <em>Leave empty to NOT create Billwerk Customer / Contract on Drupal user registration.</em>'),
      '#default_value' => $this->config('billwerk_subscriptions_handler_default.settings')->get('billwerk_registration_plan_variant_id_sandbox'),
      '#states' => [
        'visible' => [
          ':input[name="on_user_registration_create_subscription"]' => ['checked' => TRUE],
        ],
      ],
    ];
    $form['settings']['billwerk_registration_plan_variant_id_production'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Billwerk Plan Variant ID for registration (Production)'),
      '#description' => $this->t('The Billwerk Plan Variant ID used for Billwerk Customer / Contract creation on Drupal user registration. Enter the plan variant id from the Production environment here. <em>Leave empty to NOT create Billwerk Customer / Contract on Drupal user registration.</em>'),
      '#default_value' => $this->config('billwerk_subscriptions_handler_default.settings')->get('billwerk_registration_plan_variant_id_production'),
      '#states' => [
        'visible' => [
          ':input[name="on_user_registration_create_subscription"]' => ['checked' => TRUE],
        ],
      ],
    ];
    $form['settings']['on_user_login_refresh_subscription'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('On login refresh subscription'),
      '#default_value' => $config->get('on_user_login_refresh_subscription'),
      '#description' => $this->t('Refreshes the user subscription from Billwerk on Drupal user login'),
    ];
    $form['settings']['on_user_delete_delete_customer'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('On user deletion delete the Billwerk Customer'),
      '#default_value' => $config->get('on_user_delete_delete_customer'),
      '#description' => $this->t('Deletes the Billwerk customer, if the Drupal user account is deleted. Billwerk will eventually archive the contract, if required.'),
    ];

    $form['settings']['fetch_overwrite_status'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Fetch and override the subscriber Drupal user status from SaaS'),
      '#default_value' => $config->get('fetch_overwrite_status'),
      '#description' => $this->t('Fetched SaaS value should overwrite the user account status value'),
    ];
    $form['settings']['fetch_overwrite_mail'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Fetch and override the subscriber Drupal user mail from SaaS'),
      '#default_value' => $config->get('fetch_overwrite_mail'),
      '#description' => $this->t('Fetched SaaS value should overwrite the user account mail value'),
    ];
    $form['settings']['disable_drupal_mail_edit'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Disable email address change in user profile'),
      '#default_value' => $config->get('disable_drupal_mail_edit'),
      '#description' => $this->t('SaaS should be the leading system for user data. To prevent different email addresses for the same account, you typically want to disable email address editing in user profiles.'),
      '#states' => [
        'visible' => [
          ':input[name="fetch_overwrite_mail"]' => ['checked' => TRUE],
        ],
      ],
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $this->config('billwerk_subscriptions_handler_default.settings')
      ->set('on_user_registration_create_subscription', $form_state->getValue('on_user_registration_create_subscription'))
      ->set('billwerk_registration_plan_variant_id_sandbox', $form_state->getValue('billwerk_registration_plan_variant_id_sandbox'))
      ->set('billwerk_registration_plan_variant_id_production', $form_state->getValue('billwerk_registration_plan_variant_id_production'))
      ->set('on_user_login_refresh_subscription', $form_state->getValue('on_user_login_refresh_subscription'))
      ->set('on_user_delete_delete_customer', $form_state->getValue('on_user_delete_delete_customer'))
      ->set('fetch_overwrite_status', $form_state->getValue('fetch_overwrite_status'))
      ->set('fetch_overwrite_mail', $form_state->getValue('fetch_overwrite_mail'))
      ->set('disable_drupal_mail_edit', $form_state->getValue('disable_drupal_mail_edit'))
      ->save();
    parent::submitForm($form, $form_state);
  }

}
