<?php

declare(strict_types=1);

namespace Drupal\billwerk_subscriptions_manage\Form;

use Drupal\billwerk_subscriptions\Exception\SubscriberException;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides a Billwerk Subscriptions Manage form.
 */
final class ComponentsUnsubscribeForm extends ChangeFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'billwerk_subscriptions_manage_components_unsubscribe';
  }

  /**
   * {@inheritdoc}
   */
  public function buildSelectionForm(array $form, FormStateInterface $form_state): array {
    $this->buildComponentsUnsubscribeFormElement($form, $form_state);
    $form['components_unsubscribe']['#required'] = TRUE;

    if (empty($form['components_unsubscribe']['#options'])) {
      return [
        'message' => [
          '#type' => 'inline_template',
          '#template' => '<div class="messages messages--warning"><div class="message">{{ "No add-ons to cancel in your subscription. Please contact us for individual cases."|t }}</div></div>',
          '#context' => [],
        ],
      ];
    }

    $form['actions']['#type'] = 'actions';
    $form['actions']['proceed'] = [
      '#type' => 'submit',
      '#value' => $this->t('Next'),
      '#validate' => ['::validateSelectionForm'],
      '#submit' => ['::proceedToConfirm'],
      '#button_type' => 'primary',
    ];

    return $form;
  }

  /**
   *
   */
  public function validateSelectionForm(array &$form, FormStateInterface $form_state) {
    $activeComponents = $this->subscriberBillwerkEntitiesHelper->getActiveBillwerkComponents();
    $selectedComponents = array_filter($form_state->getValue('components_unsubscribe'));

    // @todo Check finally:
    if (!empty(array_diff_key($selectedComponents, $this->billwerkEntitiesHelper->getComponentsUnsubscribeSelectOptions(array_keys($activeComponents))))) {
      $form_state->setErrorByName('components_unsubscribe', $this->t('Invalid component selected'));
    }
  }

  /**
   *
   */
  protected function buildConfirmForm(array $form, FormStateInterface $form_state): array {
    $planVariantId = $this->subscriberBillwerkEntitiesHelper->getActiveBillwerkPlanVariant()->getBillwerkId($this->environment->getEnvironmentName());
    $endComponentSubscriptionIds = $this->valueGetComponentsUnsubscribe($form_state);

    $billwerkOrderObj = $this->subscriber->billwerkChangeSubscription(
    NULL,
    [],
    $endComponentSubscriptionIds,
    // No coupon:
    '',
    // Cancelation should happen at the end of the contract period:
    FALSE,
    // We need a committable (non-preview) order:
    FALSE,
    // We commit this order after confirmation:
    FALSE,
     );
    // dsm($billwerkOrderObj);
    $form_state->set('billwerkOrder', $billwerkOrderObj);
    $form_state->set('step', 'confirm');

    $this->buildOrderTableFormElement($form, $form_state, $billwerkOrderObj);
    $this->buildDowngradeOrderTermsFormElement($form, $form_state);
    $this->buildOrderActionsFormElement($form, $form_state, $this->t('Confirm add-on cancelation'));

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    dsm($form_state->get('billwerkOrder'));
    $billwerkOrderObj = $form_state->get('billwerkOrder');
    if (!empty($billwerkOrderObj) && !empty($billwerkOrderObj->Id)) {
      $response = $this->api->commitOrder($billwerkOrderObj->Id, []);
      $this->messenger()->addStatus($this->t('The selected add-ons have been canceled.'));
      $form_state->setRedirect('billwerk_subscriptions_manage.current_user_subscription');
    }
    else {
      throw new SubscriberException('Order was not committed, because order id could not be determined.');
    }

  }

}
