<?php

namespace Drupal\billwerk_subscriptions\Event;

use Drupal\Component\Serialization\Json;
use Symfony\Contracts\EventDispatcher\Event;

/**
 * Low level event that is fired, if a webhook was called by Billwerk (incoming).
 */
class BillwerkWebhookEvent extends Event {

  const EVENT_NAME_PREFIX = 'BillwerkWebhookEvent.';

  /**
   * The decoded data passed to the webhook.
   *
   * @var mixed
   */
  protected readonly mixed $data;

  /**
   * The Billwerk event name.
   *
   * @var string
   */
  protected readonly string $eventName;

  /**
   *
   */
  public function __construct(protected readonly string $rawDataString) {
    $this->data = Json::decode($rawDataString);
    $this->eventName = $this->extractDataValue('Event');
  }

  /**
   *
   */
  public function extractDataValue(string $key): mixed {
    return $this->data[$key] ?? NULL;
  }

  /**
   *
   */
  public function getData(): mixed {
    return $this->data;
  }

  /**
   *
   */
  public function getRawDataString(): string {
    return $this->rawDataString;
  }

  /**
   *
   */
  public function getEventName(): string {
    return $this->eventName;
  }

}
