<?php

namespace Drupal\billwerk_subscriptions\Event;

use Drupal\billwerk_subscriptions\Subscriber;
use Symfony\Contracts\EventDispatcher\Event;

/**
 * High level event, fired if a Drupal user's Billwerk contract change was detected.
 *
 * This event is fired when a change to a User's Billwerk Contract was
 * detected, so that you can react to this in Drupal without
 * having to mess arround with the lower level webhooks.
 *
 * Also consider using the SubscriberRefreshUserEvent, which should be
 * used to execute changes to the user account instead of this
 * specific event.
 *
 * This will not be called, if a new contract is created or a contract is
 * entirely deleted.
 */
class SubscriberContractChangedEvent extends Event {

  /**
   * Constructor.
   *
   * @param \Drupal\billwerk_subscriptions\Subscriber $subscriber
   */
  public function __construct(
        protected readonly Subscriber $subscriber
  ) {
  }

  /**
   * Gets the Subscriber whose Contract data changed.
   *
   * @return \Drupal\billwerk_subscriptions\Subscriber
   */
  public function getSubscriber(): Subscriber {
    return $this->subscriber;
  }

}
